.. include:: /_includes/wip_prolog.rst

:mod:`stix.utils.idgen` Module
==================================

.. module:: stix.utils.idgen

Classes
-------

.. autoclass:: IDGenerator
	:show-inheritance:
	:members:

.. autoclass:: InvalidMethodError
	:show-inheritance:
	:members:

Functions
---------

.. autofunction:: _get_generator

.. autofunction:: set_id_namespace

.. autofunction:: set_id_method

.. autofunction:: get_id_namespace

.. autofunction:: get_id_namespace_alias

.. autofunction:: create_id

Constants
---------

.. autodata:: __generator

.. autodata:: EXAMPLE_NAMESPACE
